@@ -4,9 +4,10 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Union, cast
 from starlite.handlers import BaseRouteHandler
 from starlite.utils import normalize_path
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from typing import Type
 
+    from pydantic.fields import FieldInfo
     from starlette.middleware import Middleware
     from starlette.middleware.base import BaseHTTPMiddleware
 
@@ -36,6 +37,7 @@ class Controller:
         "guards",
         "middleware",
         "owner",
+        "parameters",
         "path",
         "response_class",
         "response_headers",
@@ -49,22 +51,14 @@ class Controller:
     guards: Optional[List["Guard"]]
     middleware: Optional[List[Union["Middleware", "Type[BaseHTTPMiddleware]", "Type[MiddlewareProtocol]"]]]
     owner: "Router"
+    parameters: Optional[Dict[str, "FieldInfo"]]
     path: str
     response_class: Optional["Type[Response]"]
     response_headers: Optional[Dict[str, "ResponseHeader"]]
     tags: Optional[List[str]]
 
     def __init__(self, owner: "Router"):
-        for key in [
-            "after_request",
-            "before_request",
-            "dependencies",
-            "exception_handlers",
-            "guards",
-            "middleware",
-            "response_class",
-            "response_headers",
-        ]:
+        for key in self.__slots__:
             if not hasattr(self, key):
                 setattr(self, key, None)
 
